<?php declare(strict_types=1);

namespace Infomaker\Everyware\Base;

class ThemeMods
{
    /**
     * Returns all mods with the requested prefix
     * Example: mod article_author_details will be fetched with $prefix=article
     * 
     * @param string $prefix of the mods
     * @return array
     */

    public static function getModsByPrefix(string $prefix): array
    {
        return array_filter(static::getAllMods(), function ($mod) use ($prefix) {
            if (is_string($mod) && preg_match("/(^" . $prefix . "_)/", $mod)) {
                return $mod;
            }
        }, ARRAY_FILTER_USE_KEY);
    }

    public static function getAllMods(): array
    {
        return get_theme_mods() ?? [];
    }
    
    public static function getSingleMod(string $mod, string $default = ''): string
    {
        return get_theme_mod($mod, $default);
    }
}
