<?php

namespace Spec\Infomaker\Everyware\Base\Admin;

use Infomaker\Everyware\Base\Admin\Form;
use PhpSpec\ObjectBehavior;
use Prophecy\Argument;

class FormSpec extends ObjectBehavior
{
    public function let()
    {
        $this->beConstructedWith('field_prefix', [
            'headline' => '',
            'has_headline' => false,
            'links' => [],
        ]);
    }

    public function it_is_initializable()
    {
        $this->shouldHaveType(Form::class);
    }

    public function it_should_generate_proper_form_data()
    {
        $this->getFormData()->shouldReturn([
            'headline' => [
                'id' => 'field-prefix-headline',
                'name' => 'field-prefix[headline]',
                'value' => ''
            ],
            'has_headline' => [
                'id' => 'field-prefix-has_headline',
                'name' => 'field-prefix[has_headline]',
                'value' => false
            ],
            'links' => [],
        ]);
    }

    public function it_supports_overriding_of_fields_uppon_getting_data()
    {
        $this->getFormData([
            'headline' => 'new Headline',
            'has_headline' => true
        ])->shouldReturn([
            'headline' => [
                'id' => 'field-prefix-headline',
                'name' => 'field-prefix[headline]',
                'value' => 'new Headline'
            ],
            'has_headline' => [
                'id' => 'field-prefix-has_headline',
                'name' => 'field-prefix[has_headline]',
                'value' => true
            ],
            'links' => []
        ]);

    }

    public function it_should_not_include_unregistered_fields()
    {
        $this->getFormData([
            'unregistered_string' => '',
            'unregistered_bool' => true,
            'unregistered_array' => []
        ])->shouldReturn([
            'headline' => [
                'id' => 'field-prefix-headline',
                'name' => 'field-prefix[headline]',
                'value' => ''
            ],
            'has_headline' => [
                'id' => 'field-prefix-has_headline',
                'name' => 'field-prefix[has_headline]',
                'value' => false
            ],
            'links' => [],
        ]);

    }

    public function it_has_support_for_list_fields()
    {
        $this->getFormData([
            'links' => ['first_link']
        ])->shouldReturn([
            'headline' => [
                'id' => 'field-prefix-headline',
                'name' => 'field-prefix[headline]',
                'value' => ''
            ],
            'has_headline' => [
                'id' => 'field-prefix-has_headline',
                'name' => 'field-prefix[has_headline]',
                'value' => false
            ],
            'links' => [
                'id' => 'field-prefix-links',
                'name' => 'field-prefix[links][]',
                'value' => ['first_link']
            ],
        ]);
    }

    public function it_supports_field_objects()
    {
        $this->getFormData([
            'links' => [
                ['title' => 'first_link', 'url' => 'http://example.com'],
                ['title' => 'second_link', 'url' => 'http://example2.com', 'extra_value' => 'unique']
            ]
        ])->shouldReturn([
            'headline' => [
                'id' => 'field-prefix-headline',
                'name' => 'field-prefix[headline]',
                'value' => ''
            ],
            'has_headline' => [
                'id' => 'field-prefix-has_headline',
                'name' => 'field-prefix[has_headline]',
                'value' => false
            ],
            'links' => [
                [
                    'title' => [
                        'id' => 'field-prefix-links-0-title',
                        'name' => 'field-prefix[links][0][title]',
                        'value' => 'first_link',
                    ],
                    'url' => [
                        'id' => 'field-prefix-links-0-url',
                        'name' => 'field-prefix[links][0][url]',
                        'value' => 'http://example.com',
                    ]
                ],
                [
                    'title' => [
                        'id' => 'field-prefix-links-1-title',
                        'name' => 'field-prefix[links][1][title]',
                        'value' => 'second_link',
                    ],
                    'url' => [
                        'id' => 'field-prefix-links-1-url',
                        'name' => 'field-prefix[links][1][url]',
                        'value' => 'http://example2.com',
                    ],
                    'extra_value' => [
                        'id' => 'field-prefix-links-1-extra_value',
                        'name' => 'field-prefix[links][1][extra_value]',
                        'value' => 'unique',
                    ]
                ]
            ],
        ]);
    }
}
